@@ -1,6 +1,6 @@
 package Mongoose::Engine::Base;
 BEGIN {
-  $Mongoose::Engine::Base::VERSION = '0.09';
+  $Mongoose::Engine::Base::VERSION = '0.10';
 }
 BEGIN {
   $Mongoose::Engine::Base::VERSION = '0.06';
@@ -418,10 +418,19 @@ sub query {
 }
 
 sub find_one {
-    my ($self,$query,$fields, $scope) = @_;
-    my $doc = $self->collection->find_one( $query, $fields );
-    return undef unless defined $doc;
-    return $self->expand( $doc, $fields, $scope );
+    my $self = shift;
+    my $doc;
+    if( @_ == 1 && ! ref $_[0] ) {
+        $doc = $self->collection->find_one({ _id=>MongoDB::OID->new( value=>$_[0] ) });
+        return undef unless defined $doc;
+        return $self->expand( $doc );
+    } 
+    else {
+        my ($query,$fields, $scope) = @_;
+        $doc = $self->collection->find_one( $query, $fields );
+        return undef unless defined $doc;
+        return $self->expand( $doc, $fields, $scope );
+    }
 }
 
 =head1 NAME
@@ -430,7 +439,7 @@ Mongoose::Engine::Base - heavy lifting done here
 
 =head1 VERSION
 
-version 0.03
+version 0.10
 
 =head1 DESCRIPTION
 
@@ -444,6 +453,17 @@ Replace it with your engine if you want.
 Just like L<MongoDB::Collection/find_one>, but blesses the hash document
 into your class package.
 
+Also has a handy mode which allows
+retrieving an C<_id> directly from an string:
+
+   my $author = Author->find_one( '4dd77f4ebf4342d711000000' ); 
+
+Which expands onto:
+
+   my $author = Author->find_one({
+       _id=>MongoDB::OID->new( value=>'4dd77f4ebf4342d711000000' )
+   }); 
+
 =head2 find
 
 Just like L<MongoDB::Collection/find>, but returns
@@ -487,5 +507,4 @@ foreign object ids.
 
 =cut
 
-1;
-
+1;
\ No newline at end of file
